-- BEGIN COPYRIGHT
-- *************************************************************************
-- Licensed Materials - Property of IBM 
-- 5724-L01, 5655-N53, 5724-I82, 5655-R15
-- (C) Copyright IBM Corporation 2010. All rights reserved. 
-- US Government Users Restricted Rights - Use, duplication, or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- *************************************************************************
-- END COPYRIGHT
--


SET CURRENT SCHEMA = '@SCHEMA@'

;


CREATE TABLESPACE WLWT01
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE PS_WLSTORE (
    "ID" DECIMAL(30,0) NOT NULL,
    "TYPE" DECIMAL(30,0),
    "HANDLE" DECIMAL(30,0),
    "RECORD" BLOB(2G)
)
IN @DB_NAME@.WLWT01
;


CREATE LOB TABLESPACE WLW014
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE PS_WLSTORE4_LOB
    IN @DB_NAME@.WLW014
    STORES PS_WLSTORE COLUMN RECORD
;


CREATE UNIQUE INDEX PS_WLSTORE4_I
    ON PS_WLSTORE4_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT02
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_SYSTEM (
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "NAME" VARCHAR(128) NOT NULL,
    "DESCRIPTION" CLOB(2G),
    "ARCHIVED" TIMESTAMP,
    "VERSION" DECIMAL(31,0),
    "LAST_MODIFIED_BY_USER_ID" DECIMAL(31,0),
    "LAST_MODIFIED" TIMESTAMP
)
IN @DB_NAME@.WLWT02
;


CREATE LOB TABLESPACE WLW023
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_SYSTEM3_LOB
    IN @DB_NAME@.WLW023
    STORES LSW_SYSTEM COLUMN DESCRIPTION
;


CREATE UNIQUE INDEX LSW_SYSTEM3_I
    ON LSW_SYSTEM3_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT03
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TRACKING_GROUP (
    "TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "EXTERNAL_UNIQUE_ID" VARCHAR(128),
    "NAME" VARCHAR(128) NOT NULL,
    "DESCRIPTION" CLOB(2G),
    "ARCHIVED" TIMESTAMP,
    "VERSION" DECIMAL(31,0),
    "LAST_MODIFIED_BY_USER_ID" DECIMAL(31,0),
    "LAST_MODIFIED" TIMESTAMP,
    "TABLE_ID" DECIMAL(31,0),
    "SNAPSHOT_ID" CHAR(36) NOT NULL
)
IN @DB_NAME@.WLWT03
;


CREATE LOB TABLESPACE WLW035
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_TRACKING_GROUP5_LOB
    IN @DB_NAME@.WLW035
    STORES LSW_TRACKING_GROUP COLUMN DESCRIPTION
;


CREATE UNIQUE INDEX LSW_TRACKING_GROUP5_I
    ON LSW_TRACKING_GROUP5_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT04
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TRACKING_POINT (
    "TRACKING_POINT_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "EXTERNAL_UNIQUE_ID" VARCHAR(128),
    "NAME" VARCHAR(1200) NOT NULL,
    "DESCRIPTION" CLOB(2G),
    "ARCHIVED" TIMESTAMP,
    "VERSION" DECIMAL(31,0),
    "LAST_MODIFIED_BY_USER_ID" DECIMAL(31,0),
    "LAST_MODIFIED" TIMESTAMP,
    "TYPE" VARCHAR(100),
    "LOCAL_PROCESS_GUID" VARCHAR(128),
    "PROCESS_ITEM_ID" VARCHAR(200),
    "SNAPSHOT_ID" CHAR(36) NOT NULL
)
IN @DB_NAME@.WLWT04
;


CREATE LOB TABLESPACE WLW046
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_TRACKING_POINT6_LOB
    IN @DB_NAME@.WLW046
    STORES LSW_TRACKING_POINT COLUMN DESCRIPTION
;


CREATE UNIQUE INDEX LSW_TRACKING_POINT6_I
    ON LSW_TRACKING_POINT6_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT05
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TRACKED_FIELD (
    "TRACKED_FIELD_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "EXTERNAL_UNIQUE_ID" VARCHAR(128),
    "NAME" VARCHAR(128) NOT NULL,
    "DESCRIPTION" CLOB(2G),
    "FIELD_TYPE" DECIMAL(2,0) NOT NULL,
    "ARCHIVED" TIMESTAMP,
    "COLUMN_ID" DECIMAL(31,0),
    "ALLOCATED" TIMESTAMP,
    "SNAPSHOT_ID" CHAR(36) NOT NULL
)
IN @DB_NAME@.WLWT05
;


CREATE LOB TABLESPACE WLW055
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_TRACKED_FIELD5_LOB
    IN @DB_NAME@.WLW055
    STORES LSW_TRACKED_FIELD COLUMN DESCRIPTION
;


CREATE UNIQUE INDEX LSW_TRACKED_FIELD5_I
    ON LSW_TRACKED_FIELD5_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT06
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TRACKED_FIELD_USE (
    "TRACKED_FIELD_USE_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_POINT_ID" DECIMAL(31,0) NOT NULL,
    "TRACKED_FIELD_ID" DECIMAL(31,0) NOT NULL,
    "ARCHIVED" TIMESTAMP,
    "SNAPSHOT_ID" CHAR(36) NOT NULL
)
IN @DB_NAME@.WLWT06
;


CREATE TABLESPACE WLWT07
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TIMING_INTERVAL (
    "TIMING_INTERVAL_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "EXTERNAL_UNIQUE_ID" VARCHAR(128),
    "IS_AUTO" CHAR(1)
        DEFAULT 'T' NOT NULL,
    "NAME" VARCHAR(1600) NOT NULL,
    "DESCRIPTION" CLOB(2G),
    "START_BOUND" DECIMAL(2,0) NOT NULL,
    "END_BOUND" DECIMAL(2,0) NOT NULL,
    "ARCHIVED" TIMESTAMP,
    "VERSION" DECIMAL(31,0),
    "LAST_MODIFIED_BY_USER_ID" DECIMAL(31,0),
    "LAST_MODIFIED" TIMESTAMP
)
IN @DB_NAME@.WLWT07
;


CREATE LOB TABLESPACE WLW076
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_TIMING_INTERVAL6_LOB
    IN @DB_NAME@.WLW076
    STORES LSW_TIMING_INTERVAL COLUMN DESCRIPTION
;


CREATE UNIQUE INDEX LSW_TIMING_INTERVAL6_I
    ON LSW_TIMING_INTERVAL6_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT08
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TIMING_INTERVAL_BOUND (
    "TIMING_INTERVAL_BOUND_ID" DECIMAL(31,0) NOT NULL,
    "TIMING_INTERVAL_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_POINT_ID" DECIMAL(31,0) NOT NULL,
    "BOUND" DECIMAL(2,0) NOT NULL,
    "ARCHIVED" TIMESTAMP,
    "SNAPSHOT_ID" CHAR(36) NOT NULL
)
IN @DB_NAME@.WLWT08
;


CREATE TABLESPACE WLWT09
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE8K@
  
;

CREATE TABLE LSW_TASK (
    "TASK_ID" DECIMAL(31,0) NOT NULL,
    "FUNCTIONAL_TASK_ID" DECIMAL(31,0) NOT NULL,
    "IS_INSTANCE" CHAR(1)
        DEFAULT 'F' NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_USER_ID" VARCHAR(128),
    "SYSTEM_TASK_ID" VARCHAR(128),
    "SYSTEM_FUNCTIONAL_TASK_ID" VARCHAR(128),
    "BPD_NAME" VARCHAR(128),
    "STARTING_PROCESS_ID" VARCHAR(4000),
    "STARTING_PROCESS_SNAPSHOT_ID" CHAR(36),
    "ACTIVITY_NAME" VARCHAR(1160),
    "CREATED_BY_PROCESS_ITEM_ID" VARCHAR(128),
    "CREATION_TIME" TIMESTAMP,
    "START_TIME" TIMESTAMP,
    "END_TIME" TIMESTAMP,
    "STATUS" DECIMAL(31,0),
    "ASSIGNED_GROUP_ID" VARCHAR(522),
    "SNAPSHOT_ID" CHAR(36),
    "PROJECT_ID" CHAR(36),
    "MAX_STEP" DECIMAL(31,0)
        DEFAULT 0
)
IN @DB_NAME@.WLWT09
;


CREATE TABLESPACE WLWT10
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TIMING_INTERVAL_VALUE (
    "TIMING_INTERVAL_VALUE_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "TIMING_INTERVAL_ID" DECIMAL(31,0) NOT NULL,
    "FUNCTIONAL_TASK_ID" DECIMAL(31,0) NOT NULL,
    "START_TASK_ID" DECIMAL(31,0) NOT NULL,
    "START_TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "START_TRACKING_POINT_ID" DECIMAL(31,0) NOT NULL,
    "START_TRACKING_POINT_VALUE_ID" DECIMAL(31,0) NOT NULL,
    "START_TIME" TIMESTAMP,
    "END_TASK_ID" DECIMAL(31,0) NOT NULL,
    "END_TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "END_TRACKING_POINT_ID" DECIMAL(31,0) NOT NULL,
    "END_TRACKING_POINT_VALUE_ID" DECIMAL(31,0) NOT NULL,
    "END_TIME" TIMESTAMP,
    "DURATION" DECIMAL(16,0) NOT NULL
)
IN @DB_NAME@.WLWT10
;


CREATE TABLESPACE WLWT11
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TRACKING_POINT_VALUE (
    "TRACKING_POINT_VALUE_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_GROUP_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_POINT_ID" DECIMAL(31,0) NOT NULL,
    "TASK_ID" DECIMAL(31,0) NOT NULL,
    "FUNCTIONAL_TASK_ID" DECIMAL(31,0) NOT NULL,
    "TIME_STAMP" TIMESTAMP,
    "STEP_NUMBER" DECIMAL(31,0),
    "SNAPSHOT_ID" CHAR(36)
)
IN @DB_NAME@.WLWT11
;


CREATE TABLESPACE WLWT12
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_PRI_KEY (
    "TABLE_ID" VARCHAR(128) NOT NULL,
    "HIGH_KEY" DECIMAL(31,0) NOT NULL
)
IN @DB_NAME@.WLWT12
;


CREATE TABLESPACE WLWT13
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_LOAD_TRACE (
    "LOAD_TRACE_ID" DECIMAL(31,0) NOT NULL,
    "SYNCHRONIZATION_EUID" VARCHAR(128) NOT NULL,
    "LOAD_TYPE" DECIMAL(2,0) NOT NULL,
    "TIME_RECEIVED" TIMESTAMP NOT NULL,
    "TIME_VALIDATED" TIMESTAMP,
    "TIME_LOADED" TIMESTAMP,
    "TIME_DELETED" TIMESTAMP,
    "TIME_REQUEUED" TIMESTAMP,
    "STATUS" DECIMAL(2,0) NOT NULL
)
IN @DB_NAME@.WLWT13
;


CREATE TABLESPACE WLWT14
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_VIEW (
    "VIEW_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "TABLE_ID" DECIMAL(31,0),
    "VIEW_TYPE" DECIMAL(5,0),
    "NAME" VARCHAR(200),
    "CREATED_DATE" TIMESTAMP
)
IN @DB_NAME@.WLWT14
;


CREATE TABLESPACE WLWT15
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_USR_XREF (
    "USER_ID" DECIMAL(12,0) NOT NULL,
    "USER_NAME" VARCHAR(128) NOT NULL,
    "PROVIDER" VARCHAR(256)
)
IN @DB_NAME@.WLWT15
;


CREATE TABLESPACE WLWT16
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_DATA_TRANSFER_ERRORS (
    "DATA_TRANSFER_ERRORS_ID" VARCHAR(128) NOT NULL,
    "TIME_CLAIMED" TIMESTAMP,
    "CLAIMED_BY" VARCHAR(128),
    "REPROCESS" CHAR(1),
    "TIME_OF_ERROR" TIMESTAMP,
    "ERROR" CLOB(2G),
    "DATA" BLOB(2G) NOT NULL
)
IN @DB_NAME@.WLWT16
;


CREATE LOB TABLESPACE WLW166
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_DATA_TRANSFER_ERRORS6_LOB
    IN @DB_NAME@.WLW166
    STORES LSW_DATA_TRANSFER_ERRORS COLUMN ERROR
;


CREATE UNIQUE INDEX LSW_DATA_TRANSFER_ERRORS6_I
    ON LSW_DATA_TRANSFER_ERRORS6_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE LOB TABLESPACE WLW167
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_DATA_TRANSFER_ERRORS7_LOB
    IN @DB_NAME@.WLW167
    STORES LSW_DATA_TRANSFER_ERRORS COLUMN DATA
;


CREATE UNIQUE INDEX LSW_DATA_TRANSFER_ERRORS7_I
    ON LSW_DATA_TRANSFER_ERRORS7_LOB
    USING STOGROUP @STOGRP@
    
;


CREATE TABLESPACE WLWT17
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_OPTIMIZER_DATA (
    "TRACKING_POINT_VALUE_ID" DECIMAL(31,0) NOT NULL,
    "TRACKED_FIELD_ID" DECIMAL(31,0) NOT NULL,
    "NUMBER_VALUE" DECIMAL(31,6),
    "DATE_VALUE" TIMESTAMP,
    "STRING_VALUE" VARCHAR(510)
)
IN @DB_NAME@.WLWT17
;


CREATE TABLESPACE WLWT18
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_USER_MAPPINGS (
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "USER_ID" DECIMAL(31,0) NOT NULL,
    "USERNAME" VARCHAR(128) NOT NULL
)
IN @DB_NAME@.WLWT18
;


CREATE TABLESPACE WLWT19
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_SYSTEM_SCHEMA (
    "PROPNAME" VARCHAR(100) NOT NULL,
    "PROPVALUE" VARCHAR(100)
)
IN @DB_NAME@.WLWT19
;


CREATE TABLESPACE WLWT20
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_TABLE (
    "TABLE_ID" DECIMAL(31,0) NOT NULL,
    "SYSTEM_ID" DECIMAL(31,0) NOT NULL,
    "TRACKING_GROUP_NAME" VARCHAR(128) NOT NULL,
    "EXTERNAL_UNIQUE_ID" VARCHAR(128),
    "ARCHIVED" TIMESTAMP,
    "VERSION" DECIMAL(31,0),
    "LAST_MODIFIED_BY_USER_ID" DECIMAL(31,0),
    "LAST_MODIFIED" TIMESTAMP,
    "TABLE_NAME" VARCHAR(200),
    "REP_STATUS" DECIMAL(2,0),
    "REP_ACTION" DECIMAL(2,0),
    "NEW_TABLE_NAME" VARCHAR(200),
    "NEW_CONSTR_PREFIX" VARCHAR(28)
)
IN @DB_NAME@.WLWT20
;


CREATE TABLESPACE WLWT21
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_COLUMN (
    "COLUMN_ID" DECIMAL(31,0) NOT NULL,
    "TABLE_ID" DECIMAL(31,0) NOT NULL,
    "TRACKED_FIELD_NAME" VARCHAR(128) NOT NULL,
    "EXTERNAL_UNIQUE_ID" VARCHAR(128),
    "FIELD_TYPE" DECIMAL(2,0) NOT NULL,
    "ARCHIVED" TIMESTAMP,
    "COLUMN_NAME" VARCHAR(200),
    "ALLOCATED" TIMESTAMP,
    "NEW_COLUMN_NAME" VARCHAR(200),
    "NEW_FIELD_TYPE" DECIMAL(2,0)
)
IN @DB_NAME@.WLWT21
;


CREATE TABLESPACE WLWT22
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  SEGSIZE 32
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE YES
  CCSID UNICODE
  BUFFERPOOL @BPTABLE4K@    

;

CREATE TABLE LSW_SNAPSHOT (
    "SNAPSHOT_ID" CHAR(36) NOT NULL,
    "NAME" VARCHAR(128),
    "DESCRIPTION" CLOB(2G),
    "SHORT_NAME" VARCHAR(128),
    "ARCHIVED" TIMESTAMP
)
IN @DB_NAME@.WLWT22
;


CREATE LOB TABLESPACE WLW223
   IN @DB_NAME@ USING STOGROUP @STOGRP@
   NOT LOGGED BUFFERPOOL @BPLOB4K@

;


CREATE AUX TABLE LSW_SNAPSHOT3_LOB
    IN @DB_NAME@.WLW223
    STORES LSW_SNAPSHOT COLUMN DESCRIPTION
;


CREATE UNIQUE INDEX LSW_SNAPSHOT3_I
    ON LSW_SNAPSHOT3_LOB
    USING STOGROUP @STOGRP@
    
;



CREATE UNIQUE INDEX WLC_WLSTORE_PK
    ON PS_WLSTORE
    ("ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE PS_WLSTORE
    ADD CONSTRAINT WLC_WLSTORE_PK
    PRIMARY KEY(
       "ID")

;



CREATE UNIQUE INDEX LSWC_SYSTEM_PK
    ON LSW_SYSTEM
    ("SYSTEM_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_SYSTEM
    ADD CONSTRAINT LSWC_SYSTEM_PK
    PRIMARY KEY(
       "SYSTEM_ID")

;



CREATE UNIQUE INDEX LSWC_TRCKNGGRP_PK
    ON LSW_TRACKING_GROUP
    ("TRACKING_GROUP_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKING_GROUP
    ADD CONSTRAINT LSWC_TRCKNGGRP_PK
    PRIMARY KEY(
       "TRACKING_GROUP_ID")

;



CREATE UNIQUE INDEX LSWC_TRCKNGPNT_PK
    ON LSW_TRACKING_POINT
    ("TRACKING_POINT_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKING_POINT
    ADD CONSTRAINT LSWC_TRCKNGPNT_PK
    PRIMARY KEY(
       "TRACKING_POINT_ID")

;



CREATE UNIQUE INDEX LSWC_TRCKDFELD_PK
    ON LSW_TRACKED_FIELD
    ("TRACKED_FIELD_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKED_FIELD
    ADD CONSTRAINT LSWC_TRCKDFELD_PK
    PRIMARY KEY(
       "TRACKED_FIELD_ID")

;



CREATE UNIQUE INDEX LSWC_TRCKFLDUS_PK
    ON LSW_TRACKED_FIELD_USE
    ("TRACKED_FIELD_USE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKED_FIELD_USE
    ADD CONSTRAINT LSWC_TRCKFLDUS_PK
    PRIMARY KEY(
       "TRACKED_FIELD_USE_ID")

;



CREATE UNIQUE INDEX LSWC_TMNGNTRVL_PK
    ON LSW_TIMING_INTERVAL
    ("TIMING_INTERVAL_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TIMING_INTERVAL
    ADD CONSTRAINT LSWC_TMNGNTRVL_PK
    PRIMARY KEY(
       "TIMING_INTERVAL_ID")

;



CREATE UNIQUE INDEX LSWC_TMNGNTRVBD_PK
    ON LSW_TIMING_INTERVAL_BOUND
    ("TIMING_INTERVAL_BOUND_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TIMING_INTERVAL_BOUND
    ADD CONSTRAINT LSWC_TMNGNTRVBD_PK
    PRIMARY KEY(
       "TIMING_INTERVAL_BOUND_ID")

;



CREATE UNIQUE INDEX LSWC_TASK_PK
    ON LSW_TASK
    ("TASK_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TASK
    ADD CONSTRAINT LSWC_TASK_PK
    PRIMARY KEY(
       "TASK_ID")

;



CREATE UNIQUE INDEX LSWC_TMNGNTRVLL_PK
    ON LSW_TIMING_INTERVAL_VALUE
    ("TIMING_INTERVAL_VALUE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TIMING_INTERVAL_VALUE
    ADD CONSTRAINT LSWC_TMNGNTRVLL_PK
    PRIMARY KEY(
       "TIMING_INTERVAL_VALUE_ID")

;



CREATE UNIQUE INDEX LSWC_TRCKNGPNTL_PK
    ON LSW_TRACKING_POINT_VALUE
    ("TRACKING_POINT_VALUE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKING_POINT_VALUE
    ADD CONSTRAINT LSWC_TRCKNGPNTL_PK
    PRIMARY KEY(
       "TRACKING_POINT_VALUE_ID")

;



CREATE UNIQUE INDEX LSWC_PRI_KEY_PK
    ON LSW_PRI_KEY
    ("TABLE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_PRI_KEY
    ADD CONSTRAINT LSWC_PRI_KEY_PK
    PRIMARY KEY(
       "TABLE_ID")

;



CREATE UNIQUE INDEX LSWC_LOADTRACE_PK
    ON LSW_LOAD_TRACE
    ("LOAD_TRACE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_LOAD_TRACE
    ADD CONSTRAINT LSWC_LOADTRACE_PK
    PRIMARY KEY(
       "LOAD_TRACE_ID")

;



CREATE UNIQUE INDEX LSWC_VIEW_PK
    ON LSW_VIEW
    ("VIEW_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_VIEW
    ADD CONSTRAINT LSWC_VIEW_PK
    PRIMARY KEY(
       "VIEW_ID")

;



CREATE UNIQUE INDEX LSWC_UXREF_PK
    ON LSW_USR_XREF
    ("USER_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_USR_XREF
    ADD CONSTRAINT LSWC_UXREF_PK
    PRIMARY KEY(
       "USER_ID")

;



CREATE UNIQUE INDEX LSWC_DT_ERR_PK
    ON LSW_DATA_TRANSFER_ERRORS
    ("DATA_TRANSFER_ERRORS_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_DATA_TRANSFER_ERRORS
    ADD CONSTRAINT LSWC_DT_ERR_PK
    PRIMARY KEY(
       "DATA_TRANSFER_ERRORS_ID")

;



CREATE UNIQUE INDEX LSWC_OPTDATA_PK
    ON LSW_OPTIMIZER_DATA
    ("TRACKING_POINT_VALUE_ID","TRACKED_FIELD_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_OPTIMIZER_DATA
    ADD CONSTRAINT LSWC_OPTDATA_PK
    PRIMARY KEY(
       "TRACKING_POINT_VALUE_ID",
       "TRACKED_FIELD_ID")

;



CREATE UNIQUE INDEX LSWC_USERMAP_PK
    ON LSW_USER_MAPPINGS
    ("USER_ID","SYSTEM_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_USER_MAPPINGS
    ADD CONSTRAINT LSWC_USERMAP_PK
    PRIMARY KEY(
       "USER_ID",
       "SYSTEM_ID")

;



CREATE UNIQUE INDEX LSWC_SYSSCHEMA_PK
    ON LSW_SYSTEM_SCHEMA
    ("PROPNAME")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_SYSTEM_SCHEMA
    ADD CONSTRAINT LSWC_SYSSCHEMA_PK
    PRIMARY KEY(
       "PROPNAME")

;



CREATE UNIQUE INDEX LSWC_TABLE_PK
    ON LSW_TABLE
    ("TABLE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TABLE
    ADD CONSTRAINT LSWC_TABLE_PK
    PRIMARY KEY(
       "TABLE_ID")

;



CREATE UNIQUE INDEX LSWC_COLUMN_PK
    ON LSW_COLUMN
    ("COLUMN_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_COLUMN
    ADD CONSTRAINT LSWC_COLUMN_PK
    PRIMARY KEY(
       "COLUMN_ID")

;



CREATE UNIQUE INDEX LSWC_SNAPSHOT_PK
    ON LSW_SNAPSHOT
    ("SNAPSHOT_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_SNAPSHOT
    ADD CONSTRAINT LSWC_SNAPSHOT_PK
    PRIMARY KEY(
       "SNAPSHOT_ID")

;


CREATE UNIQUE INDEX LSWC_SYSTEM_UQ0
    ON LSW_SYSTEM(
        "NAME")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGGRP_PK4
    ON LSW_TRACKING_GROUP("NAME")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKING_GROUP
    ADD CONSTRAINT LSWC_TRCKNGGRP_FK1
	FOREIGN KEY("SYSTEM_ID")
	REFERENCES LSW_SYSTEM("SYSTEM_ID")
	
;


CREATE UNIQUE INDEX LSWC_TRCKNGGRP_UQ1
    ON LSW_TRACKING_GROUP(
        "SYSTEM_ID",
        "EXTERNAL_UNIQUE_ID",
        "SNAPSHOT_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGGRP_NQ1 
    ON LSW_TRACKING_GROUP(
    "SYSTEM_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGPNT_PK4
    ON LSW_TRACKING_POINT("NAME")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKING_POINT
    ADD CONSTRAINT LSWC_TRCKNGPNT_FK0
	FOREIGN KEY("TRACKING_GROUP_ID")
	REFERENCES LSW_TRACKING_GROUP("TRACKING_GROUP_ID")
	
;


CREATE UNIQUE INDEX LSWC_TRCKNGPNT_UQ1
    ON LSW_TRACKING_POINT(
        "SYSTEM_ID",
        "EXTERNAL_UNIQUE_ID",
        "SNAPSHOT_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGPNT_NQ0 
    ON LSW_TRACKING_POINT(
    "TRACKING_GROUP_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKDFELD_PK4
    ON LSW_TRACKED_FIELD("NAME")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKED_FIELD
    ADD CONSTRAINT LSWC_TRCKDFELD_FK0
	FOREIGN KEY("TRACKING_GROUP_ID")
	REFERENCES LSW_TRACKING_GROUP("TRACKING_GROUP_ID")
	
;


CREATE UNIQUE INDEX LSWC_TRCKDFELD_UQ0
    ON LSW_TRACKED_FIELD(
        "TRACKING_GROUP_ID",
        "EXTERNAL_UNIQUE_ID",
        "SNAPSHOT_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKDFELD_NQ0 
    ON LSW_TRACKED_FIELD(
    "TRACKING_GROUP_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKED_FIELD_USE
    ADD CONSTRAINT LSWC_TRCKFLDUS_FK0
	FOREIGN KEY("TRACKED_FIELD_ID")
	REFERENCES LSW_TRACKED_FIELD("TRACKED_FIELD_ID")
	
;


ALTER TABLE LSW_TRACKED_FIELD_USE
    ADD CONSTRAINT LSWC_TRCKFLDUS_FK1
	FOREIGN KEY("TRACKING_POINT_ID")
	REFERENCES LSW_TRACKING_POINT("TRACKING_POINT_ID")
	
;


CREATE INDEX LSWC_TRCKFLDUS_NQ0 
    ON LSW_TRACKED_FIELD_USE(
    "TRACKED_FIELD_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKFLDUS_NQ1 
    ON LSW_TRACKED_FIELD_USE(
    "TRACKING_POINT_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TMNGNTRVL_PK4
    ON LSW_TIMING_INTERVAL("NAME")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TIMING_INTERVAL
    ADD CONSTRAINT LSWC_TMNGNTRVL_FK1
	FOREIGN KEY("SYSTEM_ID")
	REFERENCES LSW_SYSTEM("SYSTEM_ID")
	
;


CREATE UNIQUE INDEX LSWC_TMNGNTRVL_UQ1
    ON LSW_TIMING_INTERVAL(
        "SYSTEM_ID",
        "EXTERNAL_UNIQUE_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TMNGNTRVL_NQ1 
    ON LSW_TIMING_INTERVAL(
    "SYSTEM_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TIMING_INTERVAL_BOUND
    ADD CONSTRAINT LSWC_TMNGNTVBD_FK0
	FOREIGN KEY("TIMING_INTERVAL_ID")
	REFERENCES LSW_TIMING_INTERVAL("TIMING_INTERVAL_ID")
	
;


ALTER TABLE LSW_TIMING_INTERVAL_BOUND
    ADD CONSTRAINT LSWC_TMNGNTVBD_FK1
	FOREIGN KEY("TRACKING_POINT_ID")
	REFERENCES LSW_TRACKING_POINT("TRACKING_POINT_ID")
	
;


CREATE INDEX LSWC_TMNGNTVBD_NQ0 
    ON LSW_TIMING_INTERVAL_BOUND(
    "TIMING_INTERVAL_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TMNGNTVBD_NQ1 
    ON LSW_TIMING_INTERVAL_BOUND(
    "TRACKING_POINT_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TASK
    ADD CONSTRAINT LSWC_TASK_FK0
	FOREIGN KEY("SYSTEM_ID")
	REFERENCES LSW_SYSTEM("SYSTEM_ID")
	
;


CREATE UNIQUE INDEX LSWC_TASK_UQ0
    ON LSW_TASK(
        "SYSTEM_TASK_ID",
        "SYSTEM_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ0 
    ON LSW_TASK(
    "SYSTEM_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ1 
    ON LSW_TASK(
    "IS_INSTANCE")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ2 
    ON LSW_TASK(
    "FUNCTIONAL_TASK_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ3 
    ON LSW_TASK(
    "MAX_STEP")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ4 
    ON LSW_TASK(
    "CREATION_TIME",
    "TASK_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ5 
    ON LSW_TASK(
    "START_TIME",
    "TASK_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TASK_NQ6 
    ON LSW_TASK(
    "END_TIME",
    "TASK_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TIMING_INTERVAL_VALUE
    ADD CONSTRAINT LSWC_TMNGNTRLL_FK0
	FOREIGN KEY("TIMING_INTERVAL_ID")
	REFERENCES LSW_TIMING_INTERVAL("TIMING_INTERVAL_ID")
	
;


ALTER TABLE LSW_TIMING_INTERVAL_VALUE
    ADD CONSTRAINT LSWC_TMNGNTRLL_FK1
	FOREIGN KEY("FUNCTIONAL_TASK_ID")
	REFERENCES LSW_TASK("TASK_ID")
	
;


CREATE INDEX LSWC_TMNGNTRLL_NQ0 
    ON LSW_TIMING_INTERVAL_VALUE(
    "TIMING_INTERVAL_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TMNGNTRLL_NQ1 
    ON LSW_TIMING_INTERVAL_VALUE(
    "FUNCTIONAL_TASK_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TMNGNTRLL_UQ0 
    ON LSW_TIMING_INTERVAL_VALUE(
    "TIMING_INTERVAL_ID",
    "START_TRACKING_POINT_VALUE_ID",
    "END_TRACKING_POINT_VALUE_ID")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_TRACKING_POINT_VALUE
    ADD CONSTRAINT LSWC_TRCKNGPTL_FK0
	FOREIGN KEY("TRACKING_POINT_ID")
	REFERENCES LSW_TRACKING_POINT("TRACKING_POINT_ID")
	
;


ALTER TABLE LSW_TRACKING_POINT_VALUE
    ADD CONSTRAINT LSWC_TRCKNGPTL_FK1
	FOREIGN KEY("TASK_ID")
	REFERENCES LSW_TASK("TASK_ID")
	
;


ALTER TABLE LSW_TRACKING_POINT_VALUE
    ADD CONSTRAINT LSWC_TRCKNGPTL_FK2
	FOREIGN KEY("FUNCTIONAL_TASK_ID")
	REFERENCES LSW_TASK("TASK_ID")
	
;


ALTER TABLE LSW_TRACKING_POINT_VALUE
    ADD CONSTRAINT LSWC_TRCKNGPTL_FK3
	FOREIGN KEY("TRACKING_GROUP_ID")
	REFERENCES LSW_TRACKING_GROUP("TRACKING_GROUP_ID")
	
;


CREATE INDEX LSWC_TRCKNGPTL_NQ0 
    ON LSW_TRACKING_POINT_VALUE(
    "TRACKING_POINT_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGPTL_NQ1 
    ON LSW_TRACKING_POINT_VALUE(
    "TASK_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGPTL_NQ2 
    ON LSW_TRACKING_POINT_VALUE(
    "FUNCTIONAL_TASK_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGPTL_NQ3 
    ON LSW_TRACKING_POINT_VALUE(
    "TRACKING_GROUP_ID",
    "TRACKING_POINT_ID",
    "TRACKING_POINT_VALUE_ID",
    "TIME_STAMP")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_TRCKNGPTL_NQ4 
    ON LSW_TRACKING_POINT_VALUE(
    "TIME_STAMP",
    "TRACKING_POINT_VALUE_ID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_LDTRACE_NUQ 
    ON LSW_LOAD_TRACE(
    "SYNCHRONIZATION_EUID")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_LDTRACE_NUQ1 
    ON LSW_LOAD_TRACE(
    "LOAD_TRACE_ID",
    "SYNCHRONIZATION_EUID",
    "LOAD_TYPE",
    "TIME_RECEIVED",
    "TIME_VALIDATED",
    "TIME_LOADED",
    "TIME_DELETED",
    "TIME_REQUEUED",
    "STATUS")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_VIEW
    ADD CONSTRAINT LSWC_VIEW_FK1
	FOREIGN KEY("TABLE_ID")
	REFERENCES LSW_TABLE("TABLE_ID")
	
;


CREATE UNIQUE INDEX LSWC_VIEW_NAME_UQ
    ON LSW_VIEW(
        "NAME")
    USING STOGROUP @STOGRP@

;


CREATE UNIQUE INDEX LSWC_UXREF_UQ
    ON LSW_USR_XREF(
        "USER_NAME",
        "PROVIDER")
    USING STOGROUP @STOGRP@

;


CREATE INDEX LSWC_DT_ERR_NUQ 
    ON LSW_DATA_TRANSFER_ERRORS(
    "CLAIMED_BY",
    "REPROCESS")
    USING STOGROUP @STOGRP@

;


ALTER TABLE LSW_COLUMN
    ADD CONSTRAINT LSWC_COLUMN_FK1
	FOREIGN KEY("TABLE_ID")
	REFERENCES LSW_TABLE("TABLE_ID")
	
;


CREATE INDEX LSWC_SNAPSHOT_PK4
    ON LSW_SNAPSHOT("NAME")
    USING STOGROUP @STOGRP@

;


SET CURRENT SCHEMA = '@SCHEMA@'

;

INSERT INTO LSW_SYSTEM_SCHEMA("PROPNAME",
 "PROPVALUE") 
VALUES ('DatabaseSchemaVersion',
 '8.0.1')
;

