CREATE OR REPLACE FUNCTION LSW_CURRENTDATE_GMT RETURN DATE AS

gmtDate DATE;
gmtDateString VARCHAR2(100);

BEGIN

SELECT REPLACE(TO_CHAR(sys.standard.sys_at_time_zone(localtimestamp,'0:00'),'DD-MON-RR HH:MI:SS AM'),'.',':')
INTO gmtDateString
FROM DUAL;

gmtDate := TO_DATE(SUBSTR(gmtDateString, 1, 21), 'DD-MON-RR HH:MI:SS AM');

RETURN(gmtDate);

END;
/

CREATE OR REPLACE PROCEDURE LSW_TASK_CLOSE(userId IN NUMBER, taskId IN NUMBER, returnStatus OUT NUMBER) AS

BEGIN

DECLARE

taskUserId NUMBER;
taskGroupId NUMBER;
taskStatus VARCHAR2(2);
taskProcessRef NUMBER;
taskExecutionStatus NUMBER;

flgCanClose CHAR;

BEGIN

returnStatus := -1;

SELECT USER_ID,GROUP_ID,STATUS,START_PROCESS_REF,EXECUTION_STATUS
	   INTO taskUserId,taskGroupId,taskStatus,taskProcessRef,taskExecutionStatus
	   FROM LSW_TASK
	   WHERE TASK_ID = taskId;

/* See if we can close this task */
flgCanClose := 'F';
IF (SUBSTR(taskStatus, 1, 1) <> '3') THEN
  IF (taskProcessRef IS NULL) THEN
    flgCanClose := 'T';
  ELSE
    IF ((taskExecutionStatus = 1) OR (taskExecutionStatus = 4)) THEN
	  flgCanClose := 'T';
	END IF;
  END IF;

  /* See if we own this task */
  IF (userId <> taskUserId) THEN
    flgCanClose := 'F';
    DBMS_OUTPUT.PUT_LINE('Not the owner of task ' || taskId);
  END IF;
END IF;

/* OK, so now close this task */
IF (flgCanClose = 'T') THEN
  UPDATE LSW_TASK SET STATUS = '32', CLOSE_DATETIME = LSW_CURRENTDATE_GMT(), CLOSE_BY = userId, EXECUTION_STATUS = 1
  		 WHERE TASK_ID = taskId;
  returnStatus := 0;
END IF;

EXCEPTION

WHEN NO_DATA_FOUND THEN
  DBMS_OUTPUT.PUT_LINE('Invalid TASK_ID ' || taskId || '. No data found');

END;

END;
/

CREATE OR REPLACE PROCEDURE LSW_TASK_DELETE(userId IN NUMBER, taskId IN NUMBER, returnStatus OUT NUMBER) AS

BEGIN

DECLARE

taskUserId NUMBER;
taskGroupId NUMBER;
taskStatus VARCHAR2(2);
taskProcessRef NUMBER;
taskExecutionStatus NUMBER;

flgCanDelete CHAR;

BEGIN

returnStatus := -1;

SELECT USER_ID,GROUP_ID,STATUS,START_PROCESS_REF,EXECUTION_STATUS
	   INTO taskUserId,taskGroupId,taskStatus,taskProcessRef,taskExecutionStatus
	   FROM LSW_TASK
	   WHERE TASK_ID = taskId;

/* See if we can delete task */
flgCanDelete := 'F';
IF ((SUBSTR(taskStatus, 1, 1) = '2') OR (SUBSTR(taskStatus, 1, 1) = '3')) THEN
  IF (taskProcessRef IS NULL) THEN
    flgCanDelete := 'T';
  ELSE
    IF ((taskExecutionStatus = 1) OR (taskExecutionStatus = 4)) THEN
	  flgCanDelete := 'T';
	END IF;
  END IF;

  /* See if we own this task */
  IF (userId <> taskUserId) THEN
    flgCanDelete := 'F';
    DBMS_OUTPUT.PUT_LINE('Not the owner of task ' || taskId);
  END IF;
END IF;

/* OK, so now delete this task */
IF (flgCanDelete = 'T') THEN
  IF (SUBSTR(taskStatus, 1, 1) = '2') THEN
    UPDATE LSW_TASK SET STATUS = '92'
  		 WHERE TASK_ID = taskId;
  ELSE
    UPDATE LSW_TASK SET STATUS = '91'
  		 WHERE TASK_ID = taskId;
  END IF;

  returnStatus := 0;
END IF;

EXCEPTION

WHEN NO_DATA_FOUND THEN
  DBMS_OUTPUT.PUT_LINE('Invalid TASK_ID ' || taskId || '. No data found');

END;

END;
/


CREATE OR REPLACE PROCEDURE LSW_HOUSE_KEEPING(modeHK IN NUMBER) AS

BEGIN

DECLARE

TYPE typeStatusArray IS VARRAY(5) OF VARCHAR(2);
TYPE typeDeleteId IS TABLE OF NUMBER;

rootTaskId NUMBER;
taskId NUMBER;
taskStatus VARCHAR(2);
CURSOR curRootTask (taskId IN NUMBER) IS SELECT TASK_ID, STATUS FROM LSW_TASK WHERE ORIG_TASK_ID = taskId;
CURSOR curAllRootTasks IS SELECT DISTINCT ORIG_TASK_ID FROM LSW_TASK;
i INTEGER;
statuses typeStatusArray := typeStatusArray();
deleteIds typeDeleteId := typeDeleteId();
flgDelete CHAR(1);
flgStatusExist CHAR(1);

BEGIN

IF (modeHK = 1) THEN

  /* Delete orphaned and DELETED task attachments*/
  DELETE FROM LSW_TASK_FILE WHERE TASK_ID IN (SELECT TASK_ID FROM LSW_TASK WHERE STATUS IN (91,92));
  DELETE FROM LSW_FILE WHERE FILE_ID NOT IN (SELECT FILE_ID FROM LSW_TASK_FILE) OR FILE_ID NOT IN (SELECT FILE_ID FROM LSW_TASK,LSW_TASK_FILE WHERE LSW_TASK.TASK_ID = LSW_TASK_FILE.TASK_ID);
  DELETE FROM LSW_TASK_FILE WHERE FILE_ID NOT IN (SELECT FILE_ID FROM LSW_FILE) OR TASK_ID NOT IN (SELECT LSW_TASK.TASK_ID FROM LSW_TASK,LSW_TASK_FILE WHERE LSW_TASK.TASK_ID = LSW_TASK_FILE.TASK_ID);

  /* Delete orphaned task-scoped temporary groups */
  DELETE FROM LSW_USR_GRP_MEM_XREF WHERE GROUP_ID IN (
    SELECT g.GROUP_ID FROM LSW_USR_GRP_XREF g WHERE NOT EXISTS (SELECT 1 FROM LSW_TASK t WHERE g.GROUP_ID = ABS(t.GROUP_ID)) AND g.GROUP_TYPE = 2);
  DELETE FROM LSW_USR_GRP_XREF WHERE GROUP_ID IN (
    SELECT g.GROUP_ID FROM LSW_USR_GRP_XREF g WHERE NOT EXISTS (SELECT 1 FROM LSW_TASK t WHERE g.GROUP_ID = ABS(t.GROUP_ID)) AND g.GROUP_TYPE = 2);


ELSIF (modeHK > 1) THEN

  /* Define what task statuses we are interested in */
  IF (modeHK >= 2) THEN
    statuses.extend;
    statuses(statuses.count) := '91';
    statuses.extend;
    statuses(statuses.count) := '92';
  END IF;
  IF (modeHK >= 3) THEN
    statuses.extend;
    statuses(statuses.count) := '21';
  END IF;
  IF (modeHK >= 4) THEN
    statuses.extend;
    statuses(statuses.count) := '31';
    statuses.extend;
    statuses(statuses.count) := '32';
  END IF;

  /* Go through each root task id */
  OPEN curAllRootTasks;
  LOOP
    FETCH curAllRootTasks INTO rootTaskId;
    EXIT WHEN curAllRootTasks%NOTFOUND;

	/* Check each task belonging to the current root task group. If ALL tasks in this group belong to
	   the statuses we are interested in, then we can remove these tasks */
	flgDelete := 'T';
	deleteIds.delete;
	OPEN curRootTask (rootTaskId);
	<<lblMainLoop>>
	LOOP
      FETCH curRootTask INTO taskId,taskStatus;
      EXIT WHEN curRootTask%NOTFOUND;
	  
	  flgStatusExist := 'F';
      FOR i IN statuses.FIRST..statuses.LAST LOOP
	  IF (taskStatus = statuses(i)) THEN
	    flgStatusExist := 'T';
	    EXIT;
	  END IF;
      END LOOP;
	  IF (flgStatusExist = 'F') THEN
	    flgDelete := 'F';
	    EXIT lblMainLoop;
	  END IF;

	  /* Save the task ids to delete */
	  deleteIds.extend;
	  deleteIds(deleteIds.count) := taskId;
	END LOOP;
	CLOSE curRootTask;

	IF (flgDelete = 'T') THEN
        FOR i IN deleteIds.FIRST..deleteIds.LAST LOOP
  	    DELETE FROM LSW_TASK_NARR WHERE TASK_ID = deleteIds(i);
	    DELETE FROM LSW_TASK_FILE WHERE TASK_ID = deleteIds(i);
	    DELETE FROM LSW_TASK_ADDR WHERE TASK_ID = deleteIds(i);
	    DELETE FROM LSW_TASK_EXECUTION_CONTEXT WHERE TASK_ID = deleteIds(i);
	    DELETE FROM LSW_TASK_IPF_DATA WHERE TASK_ID = deleteIds(i);
	    DELETE FROM LSW_TASK_EXTACT_DATA WHERE TASK_ID = deleteIds(i);
	    DELETE FROM LSW_TASK WHERE TASK_ID = deleteIds(i);
	  END LOOP;
	END IF;
	
  END LOOP;

  CLOSE curAllRootTasks;

  /* Delete all attachment files that are not referenced by any task */
  DELETE FROM LSW_FILE WHERE FILE_ID NOT IN (SELECT FILE_ID FROM LSW_TASK_FILE);

  /* Delete orphaned task-scoped temporary groups */
  DELETE FROM LSW_USR_GRP_MEM_XREF WHERE GROUP_ID IN (
    SELECT g.GROUP_ID FROM LSW_USR_GRP_XREF g WHERE NOT EXISTS (SELECT 1 FROM LSW_TASK t WHERE g.GROUP_ID = ABS(t.GROUP_ID)) AND g.GROUP_TYPE = 2);
  DELETE FROM LSW_USR_GRP_XREF WHERE GROUP_ID IN (
    SELECT g.GROUP_ID FROM LSW_USR_GRP_XREF g WHERE NOT EXISTS (SELECT 1 FROM LSW_TASK t WHERE g.GROUP_ID = ABS(t.GROUP_ID)) AND g.GROUP_TYPE = 2);

END IF;

END;

END;
/

CREATE OR REPLACE PROCEDURE LSW_ERASE_TEMP_GROUPS AS

  /* This procedure deletes all temporary groups that are no longer referenced by a task. */

  groupId NUMBER;

  CURSOR groupsToDelete IS
    SELECT DISTINCT g.GROUP_ID FROM LSW_USR_GRP_XREF g WHERE NOT EXISTS (SELECT 1 FROM LSW_TASK t WHERE g.GROUP_ID = ABS(t.GROUP_ID)) AND g.GROUP_TYPE = 2;

BEGIN

  OPEN groupsToDelete;

  LOOP

    FETCH groupsToDelete INTO groupId;

    EXIT WHEN groupsToDelete%NOTFOUND;
    
    DELETE FROM LSW_USR_GRP_MEM_XREF WHERE GROUP_ID = groupId;
    DELETE FROM LSW_USR_GRP_XREF WHERE GROUP_ID = groupId;

  END LOOP;

  EXCEPTION
    WHEN OTHERS THEN
      ROLLBACK;
END;
/

CREATE OR REPLACE PROCEDURE LSW_ERASE_TASK_NO_GROUP (taskId IN NUMBER) AS

  /* This procedure deletes a task and its dependent entries. It does NOT delete temporary groups that were created for this task. */

BEGIN

  DELETE FROM LSW_TASK_ADDR WHERE TASK_ID = taskId;

  DELETE FROM LSW_TASK_EXECUTION_CONTEXT WHERE TASK_ID = taskId;

  DELETE FROM LSW_TASK_NARR WHERE TASK_ID = taskId;

  DELETE FROM LSW_TASK_FILE WHERE TASK_ID = taskId;

  DELETE FROM LSW_TASK_IPF_DATA WHERE TASK_ID = taskId;
    
  DELETE FROM LSW_TASK_EXTACT_DATA WHERE TASK_ID = taskId;

  DELETE FROM LSW_TASK WHERE TASK_ID = taskId;

  EXCEPTION
    WHEN OTHERS THEN
      ROLLBACK;

END;
/

CREATE OR REPLACE PROCEDURE LSW_ERASE_TASK (taskId IN NUMBER) AS

  /* This procedure deletes a task and its dependent entries, including temporary groups that were created for this task. */

BEGIN

  /* Delete the task itself */
  LSW_ERASE_TASK_NO_GROUP(taskId);
  
  /* Cleanup: Delete orphaned task-scoped temporary groups */
  LSW_ERASE_TEMP_GROUPS();
  
  EXCEPTION
    WHEN OTHERS THEN
      ROLLBACK;

END;
/

CREATE OR REPLACE PROCEDURE LSW_ERASE_BPD_INST_NO_GROUP (bpdInstanceId in NUMBER) AS

  /* This procedure deletes a BPD instance and its dependent entries. It does NOT delete temporary groups. */

BEGIN

    DELETE FROM LSW_BPD_INSTANCE_DOC_PROPS WHERE DOC_ID IN (SELECT DOC_ID FROM LSW_BPD_INSTANCE_DOCUMENTS WHERE BPD_INSTANCE_ID = bpdInstanceId);

    DELETE FROM LSW_BPD_INSTANCE_DOCUMENTS WHERE BPD_INSTANCE_ID = bpdInstanceId;

    DELETE FROM LSW_BPD_INSTANCE_VARIABLES WHERE BPD_INSTANCE_ID = bpdInstanceId;
    
    DELETE FROM LSW_BPD_INSTANCE_DATA WHERE BPD_INSTANCE_ID = bpdInstanceId;

    DELETE FROM LSW_BPD_NOTIFICATION WHERE BPD_INSTANCE_ID = bpdInstanceId;
    
    DELETE FROM LSW_RUNTIME_ERROR WHERE BPD_INSTANCE_ID = bpdInstanceId;

    DELETE FROM LSW_BPD_INSTANCE WHERE BPD_INSTANCE_ID = bpdInstanceId;

    DELETE FROM LSW_INST_MSG_INCL WHERE BPD_INSTANCE_ID = bpdInstanceId; 

    DELETE FROM LSW_INST_MSG_EXCL WHERE BPD_INSTANCE_ID = bpdInstanceId;
    
    EXCEPTION
      WHEN OTHERS THEN
        ROLLBACK;

END;
/

CREATE OR REPLACE PROCEDURE LSW_ERASE_BPD_INSTANCE (bpdInstanceId in NUMBER) AS

  /* This procedure deletes a BPD instance and its dependent entries, including temporary groups. */

BEGIN

    LSW_ERASE_BPD_INST_NO_GROUP(bpdInstanceId);
    
    LSW_ERASE_TEMP_GROUPS();
    
    EXCEPTION
      WHEN OTHERS THEN
        ROLLBACK;

END;
/

CREATE OR REPLACE PROCEDURE LSW_BPD_INST_DELETE_NO_GROUP (bpdInstanceId IN NUMBER) AS

  /* This procedure deletes a BPD instance and its dependent entries, as well as tasks that are part of this instance. It does NOT delete temporary groups. */

  taskId NUMBER;

  CURSOR tasksToDelete (bpdInstanceId IN NUMBER) IS
    SELECT TASK_ID
    FROM LSW_TASK
    WHERE BPD_INSTANCE_ID = bpdInstanceId;

BEGIN

  OPEN tasksToDelete(bpdInstanceId);

  LOOP

    FETCH tasksToDelete INTO taskId;

    EXIT WHEN tasksToDelete%NOTFOUND;

    LSW_ERASE_TASK_NO_GROUP(taskId);

  END LOOP;

  LSW_ERASE_BPD_INST_NO_GROUP(bpdInstanceId);

  EXCEPTION
    WHEN OTHERS THEN
      ROLLBACK;
END;
/

CREATE OR REPLACE PROCEDURE LSW_BPD_INSTANCE_DELETE (bpdInstanceId IN NUMBER) AS

  /* This procedure deletes a BPD instance and its dependent entries, as well as tasks that are part of this instance and temporary groups. */

BEGIN

  /* Delete the BPD instance itself */
  LSW_BPD_INST_DELETE_NO_GROUP(bpdInstanceId);
    
  /* Cleanup: Delete orphaned task-scoped temporary groups */
  LSW_ERASE_TEMP_GROUPS();

  EXCEPTION
    WHEN OTHERS THEN
      ROLLBACK;
END;

/
